@@ -650,7 +650,7 @@ struct grib_dumper
     void* arg;
     int depth;
     long count;
-    grib_handle* handle;
+    grib_context* context;
     grib_dumper_class* cclass;
 };
 
@@ -729,66 +729,73 @@ typedef struct grib_trie_with_rank grib_trie_with_rank;
 typedef struct grib_itrie grib_itrie;
 
 
+/* Dynamic array of strings */
 struct grib_sarray
 {
     char** v;
-    size_t size;
-    size_t n;
+    size_t size; /* capacity */
+    size_t n;    /* used size */
     size_t incsize;
     grib_context* context;
 };
 
+/* Dynamic array of objects (void*) */
 struct grib_oarray
 {
     void** v;
-    size_t size;
-    size_t n;
+    size_t size; /* capacity */
+    size_t n;    /* used size */
     size_t incsize;
     grib_context* context;
 };
 
+/* Dynamic array of doubles */
 struct grib_darray
 {
     double* v;
-    size_t size;
-    size_t n;
+    size_t size; /* capacity */
+    size_t n;    /* used size */
     size_t incsize;
     grib_context* context;
 };
 
+/* Dynamic array of integers (long) */
 struct grib_iarray
 {
     long* v;
-    size_t size;
-    size_t n;
+    size_t size; /* capacity */
+    size_t n;    /* used size */
     size_t incsize;
     size_t number_of_pop_front;
     grib_context* context;
 };
 
+/* Dynamic array of double arrays */
 struct grib_vdarray
 {
     grib_darray** v;
-    size_t size;
-    size_t n;
+    size_t size; /* capacity */
+    size_t n;    /* used size */
     size_t incsize;
     grib_context* context;
 };
 
+/* Dynamic array of string arrays */
 struct grib_vsarray
 {
     grib_sarray** v;
-    size_t size;
-    size_t n;
+    size_t size; /* capacity */
+    size_t n;    /* used size */
     size_t incsize;
     grib_context* context;
 };
 
+/* Dynamic array of integer arrays */
 struct grib_viarray
 {
     grib_iarray** v;
-    size_t size;
-    size_t n;
+    size_t size; /* capacity */
+    size_t n;    /* used size */
     size_t incsize;
     grib_context* context;
 };
