@@ -1296,8 +1296,10 @@ static int compare_all_dump_keys(grib_handle* handle1, grib_handle* handle2, gri
             prefix = (char*)xa->name;
         }
 
-        if (blacklisted(prefix))
+        if (blacklisted(prefix)) {
+            if (dofree) grib_context_free(context, prefix);
             continue;
+        }
 
         /* Compare the key itself */
         if (compare_values(options, handle1, handle2, prefix, GRIB_TYPE_UNDEFINED)) {
